@@ -5,7 +5,6 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional;
 
 use Closure;
-use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\Query\Exec\FinalizedSelectExecutor;
 use Doctrine\ORM\Query\Exec\PreparedExecutorFinalizer;
@@ -17,7 +16,6 @@ use Generator;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use ReflectionMethod;
-use Symfony\Component\VarExporter\Instantiator;
 use Symfony\Component\VarExporter\VarExporter;
 
 use function file_get_contents;
@@ -27,8 +25,6 @@ use function unserialize;
 
 class ParserResultSerializationTest extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('company');
@@ -81,11 +77,6 @@ class ParserResultSerializationTest extends OrmFunctionalTestCase
             },
         ];
 
-        $instantiatorMethod = new ReflectionMethod(Instantiator::class, 'instantiate');
-        if ($instantiatorMethod->getReturnType() === null) {
-            self::markTestSkipped('symfony/var-exporter 5.4+ is required.');
-        }
-
         yield 'symfony/var-exporter' => [
             static function (ParserResult $parserResult): ParserResult {
                 return eval('return ' . VarExporter::export($parserResult) . ';');
@@ -101,8 +92,6 @@ class ParserResultSerializationTest extends OrmFunctionalTestCase
         $this->assertInstanceOf(ParserResult::class, $unserialized);
         $this->assertInstanceOf(ResultSetMapping::class, $unserialized->getResultSetMapping());
         $this->assertEquals(['name' => [0]], $unserialized->getParameterMappings());
-
-        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/pull/11188');
         $this->assertInstanceOf(SingleSelectExecutor::class, $unserialized->getSqlExecutor());
         $this->assertIsString($unserialized->getSqlExecutor()->getSqlStatements());
     }
