@@ -6,10 +6,9 @@ namespace Doctrine\Tests\ORM\Functional\Ticket\GH11072;
 
 use Doctrine\ORM\Tools\SchemaValidator;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use PHPUnit\Framework\Attributes\RequiresPhp;
 
-/**
- * @requires PHP >= 7.4
- */
+#[RequiresPhp('8.2')]
 final class GH11072Test extends OrmFunctionalTestCase
 {
     /** @var SchemaValidator */
@@ -29,9 +28,6 @@ final class GH11072Test extends OrmFunctionalTestCase
         self::assertSame([], $ce);
     }
 
-    /**
-     * @requires PHP >= 8.2
-     */
     public function testAcceptsAdvancedSubsetOfBuiltinTypesWithoutErrors(): void
     {
         $class = $this->_em->getClassMetadata(GH11072EntityAdvanced::class);
