@@ -6,10 +6,11 @@ namespace Doctrine\Test\ORM\Functional\Ticket;
 
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use PHPUnit\Framework\Attributes\Group;
 
 final class GH6682Test extends OrmFunctionalTestCase
 {
-    /** @group GH-6682 */
+    #[Group('GH-6682')]
     public function testIssue(): void
     {
         $parsedDefinition = [
@@ -23,7 +24,7 @@ final class GH6682Test extends OrmFunctionalTestCase
 
         self::assertSame(
             ['sequenceName' => 'test_sequence', 'allocationSize' => '1', 'initialValue' => '1'],
-            $classMetadata->sequenceGeneratorDefinition
+            $classMetadata->sequenceGeneratorDefinition,
         );
     }
 }
