@@ -49,7 +49,7 @@ final class GH6740Test extends OrmFunctionalTestCase
     public function testCollectionFilteringLteOperator(): void
     {
         $product  = $this->_em->find(ECommerceProduct::class, $this->productId);
-        $criteria = Criteria::create()->where(Criteria::expr()->lte('id', $this->secondCategoryId));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->lte('id', $this->secondCategoryId));
 
         self::assertCount(2, $product->getCategories()->matching($criteria));
     }
@@ -58,7 +58,7 @@ final class GH6740Test extends OrmFunctionalTestCase
     public function testCollectionFilteringLtOperator(): void
     {
         $product  = $this->_em->find(ECommerceProduct::class, $this->productId);
-        $criteria = Criteria::create()->where(Criteria::expr()->lt('id', $this->secondCategoryId));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->lt('id', $this->secondCategoryId));
 
         self::assertCount(1, $product->getCategories()->matching($criteria));
     }
@@ -67,7 +67,7 @@ final class GH6740Test extends OrmFunctionalTestCase
     public function testCollectionFilteringGteOperator(): void
     {
         $product  = $this->_em->find(ECommerceProduct::class, $this->productId);
-        $criteria = Criteria::create()->where(Criteria::expr()->gte('id', $this->firstCategoryId));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->gte('id', $this->firstCategoryId));
 
         self::assertCount(2, $product->getCategories()->matching($criteria));
     }
@@ -76,7 +76,7 @@ final class GH6740Test extends OrmFunctionalTestCase
     public function testCollectionFilteringGtOperator(): void
     {
         $product  = $this->_em->find(ECommerceProduct::class, $this->productId);
-        $criteria = Criteria::create()->where(Criteria::expr()->gt('id', $this->firstCategoryId));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->gt('id', $this->firstCategoryId));
 
         self::assertCount(1, $product->getCategories()->matching($criteria));
     }
@@ -85,7 +85,7 @@ final class GH6740Test extends OrmFunctionalTestCase
     public function testCollectionFilteringEqualsOperator(): void
     {
         $product  = $this->_em->find(ECommerceProduct::class, $this->productId);
-        $criteria = Criteria::create()->where(Criteria::expr()->eq('id', $this->firstCategoryId));
+        $criteria = Criteria::create(true)->where(Criteria::expr()->eq('id', $this->firstCategoryId));
 
         self::assertCount(1, $product->getCategories()->matching($criteria));
     }
