@@ -5,14 +5,14 @@ declare(strict_types=1);
 use Doctrine\ORM\Mapping\ClassMetadata;
 
 $metadata->setPrimaryTable(
-    ['name' => 'updatable_column']
+    ['name' => 'updatable_column'],
 );
 
 $metadata->mapField(
     [
         'id' => true,
         'fieldName' => 'id',
-    ]
+    ],
 );
 $metadata->setIdGeneratorType(ClassMetadata::GENERATOR_TYPE_AUTO);
 
@@ -21,8 +21,8 @@ $metadata->mapField(
         'fieldName' => 'nonUpdatableContent',
         'notUpdatable' => true,
         'generated' => ClassMetadata::GENERATED_ALWAYS,
-    ]
+    ],
 );
 $metadata->mapField(
-    ['fieldName' => 'updatableContent']
+    ['fieldName' => 'updatableContent'],
 );
