@@ -11,17 +11,15 @@ use DateTimeImmutable;
 use DateTimeZone;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\ORM\Tools\Debug;
-use Doctrine\Tests\DoctrineTestCase;
+use Doctrine\Tests\OrmTestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
 use stdClass;
 
 use function print_r;
 use function strpos;
 use function substr;
-use function version_compare;
 
-use const PHP_VERSION;
-
-class DebugTest extends DoctrineTestCase
+class DebugTest extends OrmTestCase
 {
     public function testExportObject(): void
     {
@@ -95,11 +93,8 @@ class DebugTest extends DoctrineTestCase
         self::assertContains('foobar', $var->__STORAGE__);
     }
 
-    /**
-     * @param array<string, int> $expected
-     *
-     * @dataProvider provideAttributesCases
-     */
+    /** @param array<string, int> $expected */
+    #[DataProvider('provideAttributesCases')]
     public function testExportParentAttributes(TestAsset\ParentClass $class, array $expected): void
     {
         $actualRepresentation   = print_r($class, true);
@@ -127,23 +122,12 @@ class DebugTest extends DoctrineTestCase
         self::assertEquals(['foo', 'bar'], $var);
     }
 
-    /**
-     * @phpstan-return array<string, array{TestAsset\ParentClass, mixed[]}>
-     */
-    public function provideAttributesCases(): iterable
+    /** @phpstan-return array<string, array{TestAsset\ParentClass, mixed[]}> */
+    public static function provideAttributesCases(): iterable
     {
         return [
             'different-attributes' => [
                 new TestAsset\ChildClass(),
-                version_compare(PHP_VERSION, '8.1', '<') ?
-                [
-                    'childPublicAttribute' => 4,
-                    'childProtectedAttribute:protected' => 5,
-                    'childPrivateAttribute:Doctrine\Tests\ORM\Tools\TestAsset\ChildClass:private' => 6,
-                    'parentPublicAttribute' => 1,
-                    'parentProtectedAttribute:protected' => 2,
-                    'parentPrivateAttribute:Doctrine\Tests\ORM\Tools\TestAsset\ParentClass:private' => 3,
-                ] :
                 [
                     'parentPublicAttribute' => 1,
                     'parentProtectedAttribute:protected' => 2,
@@ -155,13 +139,6 @@ class DebugTest extends DoctrineTestCase
             ],
             'same-attributes' => [
                 new TestAsset\ChildWithSameAttributesClass(),
-                version_compare(PHP_VERSION, '8.1', '<') ?
-                [
-                    'parentPublicAttribute' => 4,
-                    'parentProtectedAttribute:protected' => 5,
-                    'parentPrivateAttribute:Doctrine\Tests\ORM\Tools\TestAsset\ChildWithSameAttributesClass:private' => 6,
-                    'parentPrivateAttribute:Doctrine\Tests\ORM\Tools\TestAsset\ParentClass:private' => 3,
-                ] :
                 [
                     'parentPublicAttribute' => 4,
                     'parentProtectedAttribute:protected' => 5,
