@@ -6,7 +6,7 @@ namespace Doctrine\Tests\Proxy;
 
 use Doctrine\ORM\Proxy\Autoloader;
 use PHPUnit\Framework\Attributes\DataProvider;
-use PHPUnit\Framework\Attributes\WithoutErrorHandler;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use PHPUnit\Framework\TestCase;
 
 use function class_exists;
@@ -32,7 +32,7 @@ class AutoloaderTest extends TestCase
 
     /** @param class-string $className */
     #[DataProvider('dataResolveFile')]
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testResolveFile(
         string $proxyDir,
         string $proxyNamespace,
@@ -43,7 +43,7 @@ class AutoloaderTest extends TestCase
         self::assertEquals($expectedProxyFile, $actualProxyFile);
     }
 
-    #[WithoutErrorHandler]
+    #[IgnoreDeprecations]
     public function testAutoload(): void
     {
         if (file_exists(sys_get_temp_dir() . '/AutoloaderTestClass.php')) {
